@@ -1,25 +1,30 @@
-import re
 import json
-import requests
-import time
-import yaml
 import os
-
+import re
+import time
 from typing import (
-    Sequence,
-    Optional,
-    Tuple,
     Iterable,
-    MutableMapping,
-    Union,
     List,
     Mapping,
+    MutableMapping,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
 )
 
-from dbtmetabase.models import exceptions
+import requests
+import yaml
 
 from .logger.logging import logger
-from .models.metabase import MetabaseModel, MetabaseColumn, ModelType, NullValue
+from .models import exceptions
+from .models.metabase import (
+    METABASE_MODEL_DEFAULT_SCHEMA,
+    MetabaseColumn,
+    MetabaseModel,
+    ModelType,
+    NullValue,
+)
 
 
 class MetabaseClient:
@@ -384,7 +389,10 @@ class MetabaseClient:
         if api_field["fk_target_field_id"] and not fk_target_field_id:
             fk_target_field_id = api_field["fk_target_field_id"]
 
-        body_field = {}
+        api_settings = api_field.get("settings") or {}
+        body_field = {
+            "settings": api_settings.copy(),
+        }
         if api_field.get("display_name") != column_display_name:
             body_field["display_name"] = column_display_name
         if api_field.get("description") != column_description:
@@ -393,6 +401,21 @@ class MetabaseClient:
             body_field["visibility_type"] = column_visibility
         if api_field.get("fk_target_field_id") != fk_target_field_id:
             body_field["fk_target_field_id"] = fk_target_field_id
+        if (
+            api_field.get("has_field_values") != column.has_field_values
+            and column.has_field_values
+        ):
+            body_field["has_field_values"] = column.has_field_values
+        if (
+            api_field.get("coercion_strategy") != column.coercion_strategy
+            and column.coercion_strategy
+        ):
+            body_field["coercion_strategy"] = column.coercion_strategy
+        if (
+            api_settings.get("number_style") != column.number_style
+            and column.number_style
+        ):
+            body_field["settings"]["number_style"] = column.number_style
 
         # Allow explicit null type to override detected one
         if api_field.get(semantic_type_key) != column.semantic_type and (
@@ -458,7 +481,9 @@ class MetabaseClient:
             table_schema = table.get("schema")
             # table["schema"] is null for bigquery datasets
             bigquery_schema = metadata.get("details", {}).get("dataset-id")
-            table_schema = (table_schema or bigquery_schema or "public").upper()
+            table_schema = (
+                table_schema or bigquery_schema or METABASE_MODEL_DEFAULT_SCHEMA
+            ).upper()
             table_name = table["name"].upper()
 
             if schemas_to_exclude:
