@@ -1,7 +1,6 @@
 from dataclasses import dataclass, field
 from enum import Enum
-
-from typing import Sequence, Optional, MutableMapping
+from typing import MutableMapping, Optional, Sequence
 
 # Allowed metabase.* fields
 # Must be covered by MetabaseModel attributes
@@ -14,8 +13,14 @@ METABASE_MODEL_META_FIELDS = [
 # Must be covered by MetabaseColumn attributes
 METABASE_COLUMN_META_FIELDS = METABASE_MODEL_META_FIELDS + [
     "semantic_type",
+    "has_field_values",
+    "coercion_strategy",
+    "number_style",
 ]
 
+# Default model schema (only schema in BigQuery)
+METABASE_MODEL_DEFAULT_SCHEMA = "PUBLIC"
+
 
 class ModelType(str, Enum):
     nodes = "nodes"
@@ -32,6 +37,9 @@ class MetabaseColumn:
 
     semantic_type: Optional[str] = None
     visibility_type: Optional[str] = None
+    has_field_values: Optional[str] = None
+    coercion_strategy: Optional[str] = None
+    number_style: Optional[str] = None
 
     fk_target_table: Optional[str] = None
     fk_target_field: Optional[str] = None
